/*
    DriveInfo: Displays detailed drive and partition information for all physical drives in the computer
    Copyright (C) 2011  Jeffrey Bush <jeff@coderforlife.com>

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program. If not, see <http://www.gnu.org/licenses/gpl.html>.
*/

// Describes partition types for MBR and GPT disks.

#ifndef _PARTITION_TYPES_H_
#define _PARTITION_TYPES_H_

#define INITGUID
#include <guiddef.h>

////////// MBR Partition Types ///////////////////
// From http://msdn.microsoft.com/en-us/library/aa363990(VS.85).aspx and http://www.win.tue.nl/~aeb/partitions/partition_types-1.html 
const wchar_t *mbr_types[] = {
//		00							01								02							03							04					05					06							07								08								09					0A						0B									0C								0D						0E							0F
/*00*/	L"[Unused]",				L"FAT12",						L"XENIX root",				L"XENIX usr",				L"FAT16",			L"DOS Extended",	L"FAT16 (huge)",			L"NTFS / exFAT",				L"DELL (spanning) / AIX Boot",	L"AIX Data",		L"OS/2 Boot / OPUS",	L"FAT32",							L"FAT32 (LBA)",					NULL,					L"FAT16 (LBA)",				L"DOS Extended (LBA)",
/*10*/	NULL,						L"FAT12 (hidden)",				L"Config / Diagnostics",	NULL,						L"FAT16 (hidden)",	NULL,				L"FAT16 (huge, hidden)",	L"NTFS / exFAT (hidden)",		NULL,							NULL,				NULL,					L"FAT32 (hidden)",					L"FAT32 (LBA, hidden)",			NULL,					L"FAT16 (LBA, hidden)",		NULL,
/*20*/	NULL,						NULL,							NULL,						NULL,						NULL,				NULL,				NULL,						L"Rescue (FAT32 or NTFS)",		NULL,							NULL,				L"AFS",					L"SylStor",							NULL,							NULL,					NULL,						NULL,
/*30*/	NULL,						NULL,							NULL,						NULL,						NULL,				L"JFS",				NULL,						NULL,							L"THEOS",						L"THEOS",			L"THEOS",				L"THEOS",							L"PartitionMagic Recovery",		L"Netware (hidden)",	NULL,						NULL,
/*40*/	L"Pick",					L"PPC PReP / RISC Boot",		L"LDM/SFS",					NULL,						L"GoBack",			L"Boot-US",			NULL,						NULL,							NULL,							NULL,				NULL,					NULL,								L"Oberon",						L"QNX4.x",				L"QNX4.x",					L"QNX4.x",
/*50*/	L"Lynx RTOS",				L"Novell",						NULL,						L"DM 6.0 Aux3",				L"DM 6.0 DDO",		L"EZ-Drive",		L"FAT (AT&T MS-DOS)",		L"DrivePro",					NULL,							NULL,				NULL,					NULL,								NULL,							NULL,					NULL,						NULL,
/*60*/	NULL,						L"SpeedStor",					NULL,						L"UNIX",					L"Netware 2",		L"Netware 3/4",		L"Netware SMS",				L"Novell",						L"Novell",						L"Netware 5+, NSS",	NULL,					NULL,								NULL,							NULL,					NULL,						NULL,
/*70*/	L"DiskSecure Multi-Boot",	NULL,							L"V7/x86",					NULL,						L"Scramdisk",		L"IBM PC/IX",		NULL,						L"M2FS/M2CS",					L"XOSL FS",						NULL,				NULL,					NULL,								NULL,							NULL,					NULL,						NULL,
/*80*/	L"NTFT",					L"MINIX",						L"Linux Swap / Solaris",	L"Linux",					L"Hibernation",		L"Linux Extended",	L"FAT16 (fault tolerant)",	L"NTFS (fault tolerant)",		L"Linux plaintext part tbl",	NULL,				L"Linux Kernel",		L"FAT32 (fault tolerant)",			L"FAT32 (LBA, fault tolerant)",	L"FAT12 (hidden, fd)",	L"Linux LVM",				NULL,
/*90*/	L"FAT16 (hidden, fd)",		L"DOS Extended (hidden, fd)",	L"FAT16 (huge, hidden, fd)",L"Hidden Linux",			NULL,				NULL,				L"CHRP ISO-9660",			L"FAT32 (hidden, fd)",			L"FAT32 (LBA, hidden, fd)",		NULL,				L"FAT16 (hidden, fd)",	L"DOS Extended (LBA, hidden, fd)",	NULL,							NULL,					L"ForthOS",					L"BSD/OS",
/*A0*/	L"Hibernation",				L"Hibernation",					NULL,						NULL,						NULL,				L"BSD",				L"OpenBSD",					L"NeXTStep",					L"Mac OS-X",					L"NetBSD",			NULL,					L"Mac OS-X Boot",					NULL,							NULL,					NULL,						L"MacOS X HFS",
/*B0*/	L"BootStar Dummy",			L"QNX Neurtino Power-Safe",		L"QNX Neurtino Power-Safe",	L"QNX Neurtino Power-Safe",	NULL,				NULL,				L"Corrupted FAT16",			L"BSDI / Corrupted NTFS",		L"BSDI Swap",					NULL,				NULL,					L"Acronis Boot Wizard Hidden",		L"Acronis Backup",				NULL,					L"Solaris 8 Boot",			L"Solaris",
/*C0*/	L"Valid NTFT",				NULL,							L"Hidden Linux",			L"Hidden Linux Swap",		NULL,				NULL,				L"Corrupted FAT16",			L"Syrinx Boot / Corrupted NTFS",NULL,							NULL,				NULL,					NULL,								NULL,							NULL,					NULL,						NULL,
/*D0*/	NULL,						NULL,							NULL,						NULL,						NULL,				NULL,				NULL,						NULL,							L"CP/M",						NULL,				L"Powercopy Backup",	L"CP/M",							NULL,							NULL,					L"Dell PowerEdge Server",	L"BootIt EMBRM",
/*E0*/	NULL,						NULL,							NULL,						NULL,						NULL,				NULL,				NULL,						NULL,							L"LUKS",						NULL,				NULL,					L"BeOS BFS",						L"SkyOS SkyFS",					NULL,					L"EFI Header",				L"EFI",
/*F0*/	L"Linux/PA-RISC Boot",		NULL,							NULL,						NULL,						NULL,				NULL,				NULL,						NULL,							NULL,							NULL,				L"Bochs",				L"VMware",							L"VMware Swap",					L"Linux RAID",			L"Windows NT (hidden)",		L"Xenix Bad Block Table",
};

////////// GPT Partition Types ///////////////////
// From http://msdn.microsoft.com/en-us/library/aa365449(VS.85).aspx and http://en.wikipedia.org/wiki/GUID_Partition_Table

// General
DEFINE_GUID(PARTITION_ENTRY_UNUSED_GUID,		0x00000000, 0x0000, 0x0000, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00); // 00000000-0000-0000-0000-000000000000
DEFINE_GUID(PARTITION_MBR_SCHEME_GUID,			0x024DEE41, 0x33E7, 0x11D3, 0x9D, 0x69, 0x00, 0x08, 0xC7, 0x81, 0xF3, 0x9F); // 024DEE41-33E7-11D3-9D69-0008C781F39F
DEFINE_GUID(PARTITION_SYSTEM_GUID,				0xc12a7328, 0xf81f, 0x11d2, 0xba, 0x4b, 0x00, 0xa0, 0xc9, 0x3e, 0xc9, 0x3b); // C12A7328-F81F-11D2-BA4B-00A0C93EC93B
DEFINE_GUID(PARTITION_BIOS_BOOT_GUID,			0x21686148, 0x6449, 0x6E6F, 0x74, 0x4E, 0x65, 0x65, 0x64, 0x45, 0x46, 0x49); // 21686148-6449-6E6F-744E-656564454649

// Windows
DEFINE_GUID(PARTITION_MSFT_RESERVED_GUID,		0xe3c9e316, 0x0b5c, 0x4db8, 0x81, 0x7d, 0xf9, 0x2d, 0xf0, 0x02, 0x15, 0xae); // E3C9E316-0B5C-4DB8-817D-F92DF00215AE
DEFINE_GUID(PARTITION_BASIC_DATA_GUID,			0xebd0a0a2, 0xb9e5, 0x4433, 0x87, 0xc0, 0x68, 0xb6, 0xb7, 0x26, 0x99, 0xc7); // EBD0A0A2-B9E5-4433-87C0-68B6B72699C7 (also used for Linux data)
DEFINE_GUID(PARTITION_LDM_METADATA_GUID,		0x5808c8aa, 0x7e8f, 0x42e0, 0x85, 0xd2, 0xe1, 0xe9, 0x04, 0x34, 0xcf, 0xb3); // 5808C8AA-7E8F-42E0-85D2-E1E90434CFB3
DEFINE_GUID(PARTITION_LDM_DATA_GUID,			0xaf9b60a0, 0x1431, 0x4f62, 0xbc, 0x68, 0x33, 0x11, 0x71, 0x4a, 0x69, 0xad); // AF9B60A0-1431-4F62-BC68-3311714A69AD
DEFINE_GUID(PARTITION_MSFT_RECOVERY_GUID,		0xde94bba4, 0x06d1, 0x4d40, 0xa1, 0x6a, 0xbf, 0xd5, 0x01, 0x79, 0xd6, 0xac); // DE94BBA4-06D1-4D40-A16A-BFD50179D6AC
DEFINE_GUID(PARTITION_IBM_GPFS_GUID,			0x37AFFC90, 0xEF7D, 0x4E96, 0x91, 0xC3, 0x2D, 0x7A, 0xE0, 0x55, 0xB1, 0x74); // 37AFFC90-EF7D-4E96-91C3-2D7AE055B174     

// HP-UX
DEFINE_GUID(PARTITION_HPUX_DATA_GUID,			0x75894C1E, 0x3AEB, 0x11D3, 0xB7, 0xC1, 0x7B, 0x03, 0xA0, 0x00, 0x00, 0x00); // 75894C1E-3AEB-11D3-B7C1-7B03A0000000
DEFINE_GUID(PARTITION_HPUX_SERVICE_GUID,		0xE2A1E728, 0x32E3, 0x11D6, 0xA6, 0x82, 0x7B, 0x03, 0xA0, 0x00, 0x00, 0x00); // E2A1E728-32E3-11D6-A682-7B03A0000000

// Linux
DEFINE_GUID(PARTITION_LINUX_DATA_GUID,			0xEBD0A0A2, 0xB9E5, 0x4433, 0x87, 0xC0, 0x68, 0xB6, 0xB7, 0x26, 0x99, 0xC7); // EBD0A0A2-B9E5-4433-87C0-68B6B72699C7 (also used for Windows basic data)
DEFINE_GUID(PARTITION_LINUX_RAID_GUID,			0xA19D880F, 0x05FC, 0x4D3B, 0xA0, 0x06, 0x74, 0x3F, 0x0F, 0x84, 0x91, 0x1E); // A19D880F-05FC-4D3B-A006-743F0F84911E
DEFINE_GUID(PARTITION_LINUX_SWAP_GUID,			0x0657FD6D, 0xA4AB, 0x43C4, 0x84, 0xE5, 0x09, 0x33, 0xC8, 0x4B, 0x4F, 0x4F); // 0657FD6D-A4AB-43C4-84E5-0933C84B4F4F
DEFINE_GUID(PARTITION_LINUX_LVM_GUID,			0xE6D6D379, 0xF507, 0x44C2, 0xA2, 0x3C, 0x23, 0x8F, 0x2A, 0x3D, 0xF9, 0x28); // E6D6D379-F507-44C2-A23C-238F2A3DF928
DEFINE_GUID(PARTITION_LINUX_RESERVED_GUID,		0x8DA63339, 0x0007, 0x60C0, 0xC4, 0x36, 0x08, 0x3A, 0xC8, 0x23, 0x09, 0x08); // 8DA63339-0007-60C0-C436-083AC8230908

// FreeBSD
DEFINE_GUID(PARTITION_FREEBSD_BOOT_GUID,		0x83BD6B9D, 0x7F41, 0x11DC, 0xBE, 0x0B, 0x00, 0x15, 0x60, 0xB8, 0x4F, 0x0F); // 83BD6B9D-7F41-11DC-BE0B-001560B84F0F
DEFINE_GUID(PARTITION_FREEBSD_DATA_GUID,		0x516E7CB4, 0x6ECF, 0x11D6, 0x8F, 0xF8, 0x00, 0x02, 0x2D, 0x09, 0x71, 0x2B); // 516E7CB4-6ECF-11D6-8FF8-00022D09712B
DEFINE_GUID(PARTITION_FREEBSD_SWAP_GUID,		0x516E7CB5, 0x6ECF, 0x11D6, 0x8F, 0xF8, 0x00, 0x02, 0x2D, 0x09, 0x71, 0x2B); // 516E7CB5-6ECF-11D6-8FF8-00022D09712B
DEFINE_GUID(PARTITION_FREEBSD_UFS_GUID,			0x516E7CB6, 0x6ECF, 0x11D6, 0x8F, 0xF8, 0x00, 0x02, 0x2D, 0x09, 0x71, 0x2B); // 516E7CB6-6ECF-11D6-8FF8-00022D09712B
DEFINE_GUID(PARTITION_FREEBSD_VINUM_VM_GUID,	0x516E7CB8, 0x6ECF, 0x11D6, 0x8F, 0xF8, 0x00, 0x02, 0x2D, 0x09, 0x71, 0x2B); // 516E7CB8-6ECF-11D6-8FF8-00022D09712B
DEFINE_GUID(PARTITION_FREEBSD_ZFS_GUID,			0x516E7CBA, 0x6ECF, 0x11D6, 0x8F, 0xF8, 0x00, 0x02, 0x2D, 0x09, 0x71, 0x2B); // 516E7CBA-6ECF-11D6-8FF8-00022D09712B

// Mac OS X 
DEFINE_GUID(PARTITION_APPLE_HFSP_GUID,			0x48465300, 0x0000, 0x11AA, 0xAA, 0x11, 0x00, 0x30, 0x65, 0x43, 0xEC, 0xAC); // 48465300-0000-11AA-AA11-00306543ECAC
DEFINE_GUID(PARTITION_APPLE_UFS_GUID,			0x55465300, 0x0000, 0x11AA, 0xAA, 0x11, 0x00, 0x30, 0x65, 0x43, 0xEC, 0xAC); // 55465300-0000-11AA-AA11-00306543ECAC
DEFINE_GUID(PARTITION_APPLE_ZFS_GUID,			0x6A898CC3, 0x1DD2, 0x11B2, 0x99, 0xA6, 0x08, 0x00, 0x20, 0x73, 0x66, 0x31); // 6A898CC3-1DD2-11B2-99A6-080020736631 (from Solaris /usr)
DEFINE_GUID(PARTITION_APPLE_RAID_GUID,			0x52414944, 0x0000, 0x11AA, 0xAA, 0x11, 0x00, 0x30, 0x65, 0x43, 0xEC, 0xAC); // 52414944-0000-11AA-AA11-00306543ECAC
DEFINE_GUID(PARTITION_APPLE_RAID_OFFLINE_GUID,	0x52414944, 0x5F4F, 0x11AA, 0xAA, 0x11, 0x00, 0x30, 0x65, 0x43, 0xEC, 0xAC); // 52414944-5F4F-11AA-AA11-00306543ECAC
DEFINE_GUID(PARTITION_APPLE_BOOT_GUID,			0x426F6F74, 0x0000, 0x11AA, 0xAA, 0x11, 0x00, 0x30, 0x65, 0x43, 0xEC, 0xAC); // 426F6F74-0000-11AA-AA11-00306543ECAC
DEFINE_GUID(PARTITION_APPLE_LABEL_GUID,			0x4C616265, 0x6C00, 0x11AA, 0xAA, 0x11, 0x00, 0x30, 0x65, 0x43, 0xEC, 0xAC); // 4C616265-6C00-11AA-AA11-00306543ECAC
DEFINE_GUID(PARTITION_APPLE_TV_RECOVERY_GUID,	0x5265636F, 0x7665, 0x11AA, 0xAA, 0x11, 0x00, 0x30, 0x65, 0x43, 0xEC, 0xAC); // 5265636F-7665-11AA-AA11-00306543ECAC

// Solaris 
DEFINE_GUID(PARTITION_SOLARIS_BOOT_GUID,		0x6A82CB45, 0x1DD2, 0x11B2, 0x99, 0xA6, 0x08, 0x00, 0x20, 0x73, 0x66, 0x31); // 6A82CB45-1DD2-11B2-99A6-080020736631
DEFINE_GUID(PARTITION_SOLARIS_ROOT_GUID,		0x6A85CF4D, 0x1DD2, 0x11B2, 0x99, 0xA6, 0x08, 0x00, 0x20, 0x73, 0x66, 0x31); // 6A85CF4D-1DD2-11B2-99A6-080020736631
DEFINE_GUID(PARTITION_SOLARIS_SWAP_GUID,		0x6A87C46F, 0x1DD2, 0x11B2, 0x99, 0xA6, 0x08, 0x00, 0x20, 0x73, 0x66, 0x31); // 6A87C46F-1DD2-11B2-99A6-080020736631
DEFINE_GUID(PARTITION_SOLARIS_BACKUP_GUID,		0x6A8B642B, 0x1DD2, 0x11B2, 0x99, 0xA6, 0x08, 0x00, 0x20, 0x73, 0x66, 0x31); // 6A8B642B-1DD2-11B2-99A6-080020736631
DEFINE_GUID(PARTITION_SOLARIS_USR_GUID,			0x6A898CC3, 0x1DD2, 0x11B2, 0x99, 0xA6, 0x08, 0x00, 0x20, 0x73, 0x66, 0x31); // 6A898CC3-1DD2-11B2-99A6-080020736631 (also used for Mac OS X ZFS)
DEFINE_GUID(PARTITION_SOLARIS_VAR_GUID,			0x6A8EF2E9, 0x1DD2, 0x11B2, 0x99, 0xA6, 0x08, 0x00, 0x20, 0x73, 0x66, 0x31); // 6A8EF2E9-1DD2-11B2-99A6-080020736631
DEFINE_GUID(PARTITION_SOLARIS_HOME_GUID,		0x6A90BA39, 0x1DD2, 0x11B2, 0x99, 0xA6, 0x08, 0x00, 0x20, 0x73, 0x66, 0x31); // 6A90BA39-1DD2-11B2-99A6-080020736631
DEFINE_GUID(PARTITION_SOLARIS_ALTERNATE_GUID,	0x6A9283A5, 0x1DD2, 0x11B2, 0x99, 0xA6, 0x08, 0x00, 0x20, 0x73, 0x66, 0x31); // 6A9283A5-1DD2-11B2-99A6-080020736631
DEFINE_GUID(PARTITION_SOLARIS_RESERVED_1_GUID,	0x6A945A3B, 0x1DD2, 0x11B2, 0x99, 0xA6, 0x08, 0x00, 0x20, 0x73, 0x66, 0x31); // 6A945A3B-1DD2-11B2-99A6-080020736631
DEFINE_GUID(PARTITION_SOLARIS_RESERVED_2_GUID,	0x6A9630D1, 0x1DD2, 0x11B2, 0x99, 0xA6, 0x08, 0x00, 0x20, 0x73, 0x66, 0x31); // 6A9630D1-1DD2-11B2-99A6-080020736631
DEFINE_GUID(PARTITION_SOLARIS_RESERVED_3_GUID,	0x6A980767, 0x1DD2, 0x11B2, 0x99, 0xA6, 0x08, 0x00, 0x20, 0x73, 0x66, 0x31); // 6A980767-1DD2-11B2-99A6-080020736631
DEFINE_GUID(PARTITION_SOLARIS_RESERVED_4_GUID,	0x6A96237F, 0x1DD2, 0x11B2, 0x99, 0xA6, 0x08, 0x00, 0x20, 0x73, 0x66, 0x31); // 6A96237F-1DD2-11B2-99A6-080020736631
DEFINE_GUID(PARTITION_SOLARIS_RESERVED_5_GUID,	0x6A8D2AC7, 0x1DD2, 0x11B2, 0x99, 0xA6, 0x08, 0x00, 0x20, 0x73, 0x66, 0x31); // 6A8D2AC7-1DD2-11B2-99A6-080020736631

// NetBSD
DEFINE_GUID(PARTITION_NETBSD_SWAP_GUID,			0x49F48D32, 0xB10E, 0x11DC, 0xB9, 0x9B, 0x00, 0x19, 0xD1, 0x87, 0x96, 0x48); // 49F48D32-B10E-11DC-B99B-0019D1879648
DEFINE_GUID(PARTITION_NETBSD_FFS_GUID,			0x49F48D5A, 0xB10E, 0x11DC, 0xB9, 0x9B, 0x00, 0x19, 0xD1, 0x87, 0x96, 0x48); // 49F48D5A-B10E-11DC-B99B-0019D1879648
DEFINE_GUID(PARTITION_NETBSD_LFS_GUID,			0x49F48D82, 0xB10E, 0x11DC, 0xB9, 0x9B, 0x00, 0x19, 0xD1, 0x87, 0x96, 0x48); // 49F48D82-B10E-11DC-B99B-0019D1879648
DEFINE_GUID(PARTITION_NETBSD_RAID_GUID,			0x49F48DAA, 0xB10E, 0x11DC, 0xB9, 0x9B, 0x00, 0x19, 0xD1, 0x87, 0x96, 0x48); // 49F48DAA-B10E-11DC-B99B-0019D1879648
DEFINE_GUID(PARTITION_NETBSD_CONCATENATED_GUID,	0x2DB519C4, 0xB10F, 0x11DC, 0xB9, 0x9B, 0x00, 0x19, 0xD1, 0x87, 0x96, 0x48); // 2DB519C4-B10F-11DC-B99B-0019D1879648
DEFINE_GUID(PARTITION_NETBSD_ENCRYPTED_GUID,	0x2DB519EC, 0xB10F, 0x11DC, 0xB9, 0x9B, 0x00, 0x19, 0xD1, 0x87, 0x96, 0x48); // 2DB519EC-B10F-11DC-B99B-0019D1879648

// ChromeOS
DEFINE_GUID(PARTITION_CHROME_KERNEL_GUID,		0xFE3A2A5D, 0x4F32, 0x41A7, 0xB7, 0x25, 0xAC, 0xCC, 0x32, 0x85, 0xA3, 0x09); // FE3A2A5D-4F32-41A7-B725-ACCC3285A309
DEFINE_GUID(PARTITION_CHROME_ROOTFS_GUID,		0x3CB8E202, 0x3B7E, 0x47DD, 0x8A, 0x3C, 0x7F, 0xF2, 0xA1, 0x3C, 0xFC, 0xEC); // 3CB8E202-3B7E-47DD-8A3C-7FF2A13CFCEC
DEFINE_GUID(PARTITION_CHROME_RESERVED_GUID,		0x2E0A753D, 0x9E48, 0x43B0, 0x83, 0x37, 0xB1, 0x51, 0x92, 0xCB, 0x1B, 0x5E); // 2E0A753D-9E48-43B0-8337-B15192CB1B5E


// These two arrays map GUIDs to names
const GUID *gpt_guids[] = {
	&PARTITION_ENTRY_UNUSED_GUID, &PARTITION_MBR_SCHEME_GUID, &PARTITION_SYSTEM_GUID, &PARTITION_BIOS_BOOT_GUID,
	&PARTITION_MSFT_RESERVED_GUID, &PARTITION_BASIC_DATA_GUID, &PARTITION_LDM_METADATA_GUID, &PARTITION_LDM_DATA_GUID, &PARTITION_MSFT_RECOVERY_GUID, &PARTITION_IBM_GPFS_GUID,
	&PARTITION_HPUX_DATA_GUID, &PARTITION_HPUX_SERVICE_GUID,
	/*&PARTITION_LINUX_DATA_GUID,*/ &PARTITION_LINUX_RAID_GUID, &PARTITION_LINUX_SWAP_GUID, &PARTITION_LINUX_LVM_GUID, &PARTITION_LINUX_RESERVED_GUID,
	&PARTITION_FREEBSD_BOOT_GUID, &PARTITION_FREEBSD_DATA_GUID, &PARTITION_FREEBSD_SWAP_GUID, &PARTITION_FREEBSD_UFS_GUID, &PARTITION_FREEBSD_VINUM_VM_GUID, &PARTITION_FREEBSD_ZFS_GUID,
	&PARTITION_APPLE_HFSP_GUID, &PARTITION_APPLE_UFS_GUID, /*&PARTITION_APPLE_ZFS_GUID,*/ &PARTITION_APPLE_RAID_GUID, &PARTITION_APPLE_RAID_OFFLINE_GUID, &PARTITION_APPLE_BOOT_GUID, &PARTITION_APPLE_LABEL_GUID, &PARTITION_APPLE_TV_RECOVERY_GUID,
	&PARTITION_SOLARIS_BOOT_GUID, &PARTITION_SOLARIS_ROOT_GUID, &PARTITION_SOLARIS_SWAP_GUID, &PARTITION_SOLARIS_BACKUP_GUID, &PARTITION_SOLARIS_USR_GUID, &PARTITION_SOLARIS_VAR_GUID, &PARTITION_SOLARIS_HOME_GUID, &PARTITION_SOLARIS_ALTERNATE_GUID, &PARTITION_SOLARIS_RESERVED_1_GUID, &PARTITION_SOLARIS_RESERVED_2_GUID, &PARTITION_SOLARIS_RESERVED_3_GUID, &PARTITION_SOLARIS_RESERVED_4_GUID, &PARTITION_SOLARIS_RESERVED_5_GUID,
	&PARTITION_NETBSD_SWAP_GUID, &PARTITION_NETBSD_FFS_GUID, &PARTITION_NETBSD_LFS_GUID, &PARTITION_NETBSD_RAID_GUID, &PARTITION_NETBSD_CONCATENATED_GUID, &PARTITION_NETBSD_ENCRYPTED_GUID,
	&PARTITION_CHROME_KERNEL_GUID, &PARTITION_CHROME_ROOTFS_GUID, &PARTITION_CHROME_RESERVED_GUID,
};
const wchar_t *gpt_types[] = {
	L"Entry Unused", L"MBR Partition Scheme", L"EFI System", L"BIOS Boot",
	L"Microsoft Reserved", L"Basic Data", L"LDM Metadata", L"LDM Data", L"Windows Recovery Environment", L"IBM GPFS",
	L"HPUX Data", L"HPUX Service",
	/*L"Linux Data",*/ L"Linux RAID", L"Linux Swap", L"Linux LVM", L"Linux Reserved",
	L"FreeBSD Boot", L"FreeBSD Data", L"FreeBSD Swap", L"FreeBSD UFS", L"FreeBSD Vinum VM", L"FreeBSD ZFS",
	L"Apple HFS+", L"Apple UFS", /*L"Apple ZFS",*/ L"Apple RAID", L"Apple RAID Offline", L"Apple Boot", L"Apple Label", L"Apple TV Recovery",
	L"Solaris Boot", L"Solaris Root", L"Solaris Swap", L"Solaris Backup", L"Solaris /usr", L"Solaris /var", L"Solaris /home", L"Solaris Alternate", L"Solaris Reserved", L"Solaris Reserved", L"Solaris Reserved", L"Solaris Reserved", L"Solaris Reserved", 
	L"NetBSD Swap", L"NetBSD FFS", L"NetBSD LFS", L"NetBSD RAID", L"NetBSD Concatenated", L"NetBSD Encrypted",
	L"ChromeOS Kernel", L"ChromeOS rootfs", L"ChromeOS Reserved",
};

#endif
